@@ -1,9 +1,12 @@
 /*
- * Copyright (C) 1999-2010, 2013-2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 #ifndef ISC_PLATFORM_H
@@ -180,14 +183,6 @@
  */
 #define ISC_PLATFORM_QUADFORMAT "ll"
 
-/***
- *** String functions.
- ***/
-/*
- * If the system needs strsep(), ISC_PLATFORM_NEEDSTRSEP will be defined.
- */
-#undef ISC_PLATFORM_NEEDSTRSEP
-
 /*
  * If the system needs strlcpy(), ISC_PLATFORM_NEEDSTRLCPY will be defined.
  */
@@ -306,6 +301,12 @@
  */
 #undef ISC_PLATFORM_HAVECMPXCHG
 
+/*
+ * If <stdatomic.h> is available on this architecture,
+ * ISC_PLATFORM_HAVESTDATOMIC will be defined.
+ */
+#define ISC_PLATFORM_HAVESTDATOMIC 1
+
 /*
  * Define if gcc ASM extension is available
  */
@@ -334,7 +335,7 @@
 /*
  * Define if the hash functions must be provided by OpenSSL.
  */
-#undef ISC_PLATFORM_OPENSSLHASH
+#define ISC_PLATFORM_OPENSSLHASH 1
 
 /*
  * Define if AES support is wanted
@@ -362,6 +363,7 @@
 #define LIBDNS_EXTERNAL_DATA
 #define LIBISCCC_EXTERNAL_DATA
 #define LIBISCCFG_EXTERNAL_DATA
+#define LIBNS_EXTERNAL_DATA
 #define LIBBIND9_EXTERNAL_DATA
 #define LIBTESTS_EXTERNAL_DATA
 #else /*! \brief ISC_PLATFORM_USEDECLSPEC */
@@ -385,6 +387,11 @@
 #else
 #define LIBISCCFG_EXTERNAL_DATA __declspec(dllimport)
 #endif
+#ifdef LIBNS_EXPORTS
+#define LIBNS_EXTERNAL_DATA __declspec(dllexport)
+#else
+#define LIBNS_EXTERNAL_DATA __declspec(dllimport)
+#endif
 #ifdef LIBBIND9_EXPORTS
 #define LIBBIND9_EXTERNAL_DATA __declspec(dllexport)
 #else
